# Migraion tool to import exported inception annotations to postgraphile graphql backend

## .env file
 * please copy example.env to .env and add your credentials



## To load the spacy model used for tokenizing to create the plmarker format:
 * `uv run -- spacy download en_core_web_sm`
